@@ -1,6 +1,6 @@
-/* $Id: config.c 20833 2006-04-09 18:08:17Z benny $ */
+/* $Id: config.c 21496 2006-05-04 22:12:21Z benny $ */
 /*-
- * Copyright (c) 2003-2004 Benedikt Meurer <benny@xfce.org>
+ * Copyright (c) 2003-2006 Benedikt Meurer <benny@xfce.org>
  * All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -33,6 +33,10 @@
 #include <unistd.h>
 #endif
 
+#ifdef XFCE_DISABLE_DEPRECATED
+#undef XFCE_DISABLE_DEPRECATED
+#endif
+
 #include <gmodule.h>
 
 #include <libxfcegui4/libxfcegui4.h>
